# Unleaky

##### A Simple Cli Password Manager

Unleaky is a simple python nased password manager. This documents the basic usage, more detailed document coming soon



## Basic commands

- read  - have a look at the database

- new - add new entry

- admin - change the master password

- update - update values of a database

- clear - clear the terminal

- quit - securely quit the terminal



The Master Password By Deflaut is <b>HelloWorld</b>
